@@ -1,5 +1,25 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
+#
+# Copyright 2021 The NiPreps Developers <nipreps@gmail.com>
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# We support and encourage derived works from this project, please read
+# about our expectations at
+#
+#     https://www.nipreps.org/community/licensing/
+#
 """Estimate fieldmaps for :abbr:`SDC (susceptibility distortion correction)`."""
 from nipype import logging
 from nipype.pipeline import engine as pe
@@ -39,8 +59,8 @@ def init_brainextraction_wf(name="brainextraction_wf"):
 
     """
     from nipype.interfaces.ants import N4BiasFieldCorrection
+    from niworkflows.interfaces.nibabel import IntensityClip
     from ..interfaces.brainmask import BrainExtraction
-    from ..interfaces.utils import IntensityClip
 
     wf = Workflow(name=name)
 
@@ -72,7 +92,7 @@ def init_brainextraction_wf(name="brainextraction_wf"):
         n_procs=8,
         name="n4",
     )
-    clipper_post = pe.Node(IntensityClip(p_max=100.0), name="clipper_post")
+    clipper_post = pe.Node(IntensityClip(p_min=0.01, p_max=99.9), name="clipper_post")
     masker = pe.Node(BrainExtraction(), name="masker")
 
     # fmt:off
