@@ -20,101 +20,7 @@
 #
 #     https://www.nipreps.org/community/licensing/
 #
-r"""
-Processing phase-difference and *directly measured* :math:`B_0` maps.
-
-Theory
-~~~~~~
-The displacement suffered by every voxel along the phase-encoding (PE) direction
-can be derived from Eq. (2) of [Hutton2002]_:
-
-.. math::
-
-    \Delta_\text{PE} (i, j, k) = \gamma \cdot \Delta B_0 (i, j, k) \cdot T_\text{ro},
-    \label{eq:fieldmap-1}\tag{1}
-
-where
-:math:`\Delta_\text{PE} (i, j, k)` is the *voxel-shift map* (VSM) along the *PE* direction,
-:math:`\gamma` is the gyromagnetic ratio of the H proton in Hz/T
-(:math:`\gamma = 42.576 \cdot 10^6 \, \text{Hz} \cdot \text{T}^\text{-1}`),
-:math:`\Delta B_0 (i, j, k)` is the *fieldmap variation* in T (Tesla), and
-:math:`T_\text{ro}` is the readout time of one slice of the EPI dataset
-we want to correct for distortions.
-
-Let :math:`V` represent the «*fieldmap in Hz*» (or equivalently,
-«*voxel-shift-velocity map*» as Hz are equivalent to voxels/s), with
-:math:`V(i,j,k) = \gamma \cdot \Delta B_0 (i, j, k)`, then, introducing
-the voxel zoom along the phase-encoding direction, :math:`s_\text{PE}`,
-we obtain the nonzero component of the associated displacements field
-:math:`\Delta D_\text{PE} (i, j, k)` that unwarps the target EPI dataset:
-
-.. math::
-
-    \Delta D_\text{PE} (i, j, k) = V(i, j, k) \cdot T_\text{ro} \cdot s_\text{PE}.
-    \label{eq:fieldmap-2}\tag{2}
-
-
-.. _sdc_direct_b0 :
-
-Direct B0 mapping sequences
-~~~~~~~~~~~~~~~~~~~~~~~~~~~
-Some MR schemes such as :abbr:`SEI (spiral-echo imaging)` can directly
-reconstruct an estimate of *the fieldmap in Hz*, :math:`V(i,j,k)`.
-These *fieldmaps* are described with more detail `here
-<https://cni.stanford.edu/wiki/GE_Processing#Fieldmaps>`__.
-
-This corresponds to `this section of the BIDS specification
-<https://bids-specification.readthedocs.io/en/latest/04-modality-specific-files/01-magnetic-resonance-imaging-data.html#case-3-direct-field-mapping>`__.
-
-.. _sdc_phasediff :
-
-Phase-difference B0 estimation
-~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-The fieldmap variation in T, :math:`\Delta B_0 (i, j, k)`, that is necessary to obtain
-:math:`\Delta_\text{PE} (i, j, k)` in Eq. :math:`\eqref{eq:fieldmap-1}` can be
-calculated from two subsequient :abbr:`GRE (Gradient-Recalled Echo)` echoes,
-via eq. (1) of [Hutton2002]_:
-
-.. math::
-
-    \Delta B_0 (i, j, k) = \frac{\Delta \Theta (i, j, k)}{2\pi \cdot \gamma \, \Delta\text{TE}},
-    \label{eq:fieldmap-3}\tag{3}
-
-where
-:math:`\Delta \Theta (i, j, k)` is the phase-difference map in radians,
-and :math:`\Delta\text{TE}` is the elapsed time between the two GRE echoes.
-
-For simplicity, the «*voxel-shift-velocity map*» :math:`V(i,j,k)`, which we
-can introduce in Eq. :math:`\eqref{eq:fieldmap-2}` to directly obtain
-the displacements field, can be obtained as:
-
-.. math::
-
-    V(i, j, k) = \frac{\Delta \Theta (i, j, k)}{2\pi \cdot \Delta\text{TE}}.
-    \label{eq:fieldmap-4}\tag{4}
-
-This calculation is further complicated by the fact that :math:`\Theta_i`
-(and therefore, :math:`\Delta \Theta`) are clipped (or *wrapped*) within
-the range :math:`[0 \dotsb 2\pi )`.
-It is necessary to find the integer number of offsets that make a region
-continuously smooth with its neighbors (*phase-unwrapping*, [Jenkinson2003]_).
-
-This corresponds to `this section of the BIDS specification
-<https://bids-specification.readthedocs.io/en/latest/04-modality-specific-files/01-magnetic-resonance-imaging-data.html#two-phase-images-and-two-magnitude-images>`__.
-Some scanners produce one ``phasediff`` map, where the drift between the two echos has
-already been calculated (see `the corresponding section of BIDS
-<https://bids-specification.readthedocs.io/en/latest/04-modality-specific-files/01-magnetic-resonance-imaging-data.html#case-1-phase-difference-map-and-at-least-one-magnitude-image>`__).
-
-References
-----------
-.. [Hutton2002] Hutton et al., Image Distortion Correction in fMRI: A Quantitative
-    Evaluation, NeuroImage 16(1):217-240, 2002. doi:`10.1006/nimg.2001.1054
-    <https://doi.org/10.1006/nimg.2001.1054>`__.
-.. [Jenkinson2003] Jenkinson, M. (2003) Fast, automated, N-dimensional phase-unwrapping
-    algorithm. MRM 49(1):193-197. doi:`10.1002/mrm.10354
-    <https://doi.org/10.1002/mrm.10354>`__.
-
-"""
+r"""Processing phase-difference and *directly measured* :math:`B_0` maps."""
 
 from nipype.pipeline import engine as pe
 from nipype.interfaces import utility as niu
